@@ -921,4 +921,5 @@ if __name__ == '__main__':
         unittest.main()
     else:
         runner = unittest.TextTestRunner()
-        runner.run(suite())
+        result = runner.run(suite())
+        sys.exit(not result.wasSuccessful())
